@@ -1,9 +1,9 @@
 from cacheall.Algorithms.doublylinkedlist import DoublyLinkedList as dll 
-from cacheall.EvicitonPolicies.verbose import Verbose
+from .verbose import Verbose
 # LRU cache class
 class FIFOCache:
 
-    def __init__(self, capacity,lock,verbose=0):
+    def __init__(self, capacity,lock,verbose):
         # capacity: capacity of cache
         # Initialize all variable
         self.capacity = capacity
