@@ -16,13 +16,17 @@ class LRUCache:
     def get(self, key):
         with self.lock:
             if key in self.map:
+                print("fetching",key)
                 node = self.map[key]
                 result = node.val
                 self.list.deleteNode(node)
-                self.list.addToHead(key,result)
+                self.map[key]=self.list.addToHead(key,result)
                 print('Got the value : {} for the key: {}'.format(result, key))
+                print("head of the list: ",self.list.head.key)
+                # self.list.printlist()
                 return result
             print('Did not get any value for the key: {}'.format(key))
+            # self.list.printlist()
         return -1
 
     # This method works in O(1)
@@ -33,7 +37,7 @@ class LRUCache:
                 node = self.map[key]
                 node.val = value
                 self.list.deleteNode(node)
-                self.list.addToHead(key,value)
+                self.map[key]=self.list.addToHead(key,value)
             else:
                 if self.count < self.capacity:
                     self.count += 1
@@ -42,6 +46,8 @@ class LRUCache:
                     del self.map[self.list.tail.key]
                     self.list.deleteNode(self.list.tail)
                     self.map[key]=self.list.addToHead(key,value)
+            self.list.printlist()
+
 
 
 
